@@ -72,11 +72,22 @@ GType gnome_vfs_result_get_type (void);
 GType gnome_vfs_module_callback_full_authentication_flags_get_type (void);
 #define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_FLAGS (gnome_vfs_module_callback_full_authentication_flags_get_type())
 
+GType gnome_vfs_module_callback_full_authentication_out_flags_get_type (void);
+#define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_OUT_FLAGS (gnome_vfs_module_callback_full_authentication_out_flags_get_type())
+
 /* enumerations from "gnome-vfs-utils.h" */
 
 GType gnome_vfs_make_uri_dirs_get_type (void);
 #define GNOME_VFS_TYPE_VFS_MAKE_URI_DIRS (gnome_vfs_make_uri_dirs_get_type())
 
+/* enumerations from "gnome-vfs-volume.h" */
+
+GType gnome_vfs_device_type_get_type (void);
+#define GNOME_VFS_TYPE_VFS_DEVICE_TYPE (gnome_vfs_device_type_get_type())
+
+GType gnome_vfs_volume_type_get_type (void);
+#define GNOME_VFS_TYPE_VFS_VOLUME_TYPE (gnome_vfs_volume_type_get_type())
+
 /* enumerations from "gnome-vfs-xfer.h" */
 
 GType gnome_vfs_xfer_options_get_type (void);
