@@ -529,7 +529,7 @@ get_data_for_drive (GnomeVFSDrive *drive)
 }
 
 static char *
-get_data_for_network (void)
+get_data_for_network ()
 {
 	char *data;
 
@@ -545,7 +545,7 @@ get_data_for_network (void)
 }
 
 static char *
-get_data_for_home (void)
+get_data_for_home ()
 {
 	char *data;
 	char *uri;
@@ -565,7 +565,7 @@ get_data_for_home (void)
 }
 
 static char *
-get_data_for_root (void)
+get_data_for_root ()
 {
 	char *data;
 
